searchData={"items":[{"type":"module","title":"LoggerTelegramBackend","doc":"A logger backend for [Telegram](https://telegram.org/).","ref":"LoggerTelegramBackend.html"},{"type":"module","title":"Installation - LoggerTelegramBackend","doc":"Add `:logger_telegram_backend`, `:logger_backends` and `:hackney` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:logger_telegram_backend, \"~> 3.0-rc\"},\n    {:logger_backends, \"~> 1.0\"},\n    {:hackney, \"~> 1.18\"},\n  ]\nend\n```\n\nIn your `Application.start/2` callback, add the `LoggerTelegramBackend` backend:\n\n```elixir\n@impl true\ndef start(_type, _args) do\n  LoggerBackends.add(LoggerTelegramBackend)\n\n  # ...\nend\n```","ref":"LoggerTelegramBackend.html#module-installation"},{"type":"module","title":"Configuration - LoggerTelegramBackend","doc":"First you need to create a [Telegram Bot](https://core.telegram.org/bots). Follow the [instructions here](https://core.telegram.org/bots#6-botfather) to create one and get the `token` for the bot. You will need to send a message first as bots are not allowed to contact users. Then retrieve your `chat_id` with `$ curl -X GET https://api.telegram.org/botYOUR_TOKEN/getUpdates`.\n\nThen configure the telegram `chat_id` and bot `token`:\n\n```elixir\nconfig :logger, LoggerTelegramBackend,\n  chat_id: \"$chatId\",\n  token: \"$botToken\"\n```\n\n#","ref":"LoggerTelegramBackend.html#module-configuration"},{"type":"module","title":"Options - LoggerTelegramBackend","doc":"The available options are:\n\n- `:level` - the level to be logged by this backend (either `:debug`, `:info`, `:warning` or `:error`).\n\n  Note that messages are first filtered by the general `:level` configuration for the `:logger` application.\n\n  Default: `nil` (all levels are logged)\n\n- `:metadata` - the metadata to be included in the message. Setting `:metadata` to `:all` will get all metadata.\n  Default: `[:line, :function, :module, :application, :file]`.\n\n- `:metadata_filter` - the metadata which is required in order for a message to be logged.\n\n  Default: `nil`\n\n- `:client` - If you need different functionality for the HTTP client, you can define your own module that implements the `LoggerTelegramBackend.HTTPClient` behaviour and set `client` to that module.\n\n  By default, selects the first client in the list whose application is loaded:\n\n  - `LoggerTelegramBackend.Finch` (requires `:finch`)\n  - `LoggerTelegramBackend.HackneyClient` (requires`:hackney`)\n\n- `:client_pool_opts` - The options passed to configure the pool.\n\n  See [Finch](https://hexdocs.pm/finch/Finch.html#start_link/1) or [Hackney](https://hexdocs.pm/hackney/).\n\n  Default: `[]`\n\n- `:client_request_opts` - The options passed on every request.\n\n  See [Finch](https://hexdocs.pm/finch/Finch.html#request/3) or [Hackney](https://hexdocs.pm/hackney/).\n\n  Default: `[]`\n\n#","ref":"LoggerTelegramBackend.html#module-options"},{"type":"module","title":"Examples - LoggerTelegramBackend","doc":"##","ref":"LoggerTelegramBackend.html#module-examples"},{"type":"module","title":"Custom HTTP client - LoggerTelegramBackend","doc":"1. Add a module that implements the `LoggerTelegramBackend.HTTPClient` behaviour\n2. Pass your client module to the `:client` option:\n\n   ```elixir\n   config :logger, LoggerTelegramBackend,\n     client: MyClient,\n     # ...\n   ```\n\n##","ref":"LoggerTelegramBackend.html#module-custom-http-client"},{"type":"module","title":"Metadata filter - LoggerTelegramBackend","doc":"```elixir\nconfig :logger, LoggerTelegramBackend,\n  chat_id: \"$chatId\",\n  token: \"$botToken\",\n  level: :info,\n  metadata: :all\n  metadata_filter: [application: :ui]\n```\n\n##","ref":"LoggerTelegramBackend.html#module-metadata-filter"},{"type":"module","title":"SOCKS5 proxy - LoggerTelegramBackend","doc":"```elixir\nconfig :logger, LoggerTelegramBackend,\n  chat_id: \"$chatId\",\n  token: \"$botToken\",\n  hackney_opts: [\n    proxy: {:socks5, ~c\"127.0.0.1\", 9050}\n  ]\n```\n\nSee the [hackney docs](https://github.com/benoitc/hackney#proxy-a-connection) for further information.","ref":"LoggerTelegramBackend.html#module-socks5-proxy"},{"type":"behaviour","title":"LoggerTelegramBackend.HTTPClient","doc":"Specifies the API for using a custom HTTP Client.\n\nBy default, the first HTTP client in the list whose application is loaded is selected:\n\n- `LoggerTelegramBackend.HTTPClient.Finch` (requires `:finch`)\n- `LoggerTelegramBackend.HTTPClient.Hackney` (requires`:hackney`)\n\nTo configure a different HTTP client, implement the `LoggerTelegramBackend.HTTPClient` behaviour\nand change the `:client` configuration:\n\n    config :logger, LoggerTelegramBackend,\n      client: MyHTTPClient","ref":"LoggerTelegramBackend.HTTPClient.html"},{"type":"callback","title":"LoggerTelegramBackend.HTTPClient.child_spec/0","doc":"Should return a **child specification** to start the HTTP client or `nil`.\n\nFor example, this can start a pool of HTTP connections dedicated to LoggerTelegramBackend.","ref":"LoggerTelegramBackend.HTTPClient.html#c:child_spec/0"},{"type":"callback","title":"LoggerTelegramBackend.HTTPClient.request/4","doc":"Should make an HTTP request to `url` with the given `method`, `headers` and `body`.","ref":"LoggerTelegramBackend.HTTPClient.html#c:request/4"},{"type":"type","title":"LoggerTelegramBackend.HTTPClient.body/0","doc":"HTTP request or response body.","ref":"LoggerTelegramBackend.HTTPClient.html#t:body/0"},{"type":"type","title":"LoggerTelegramBackend.HTTPClient.headers/0","doc":"HTTP request or response headers.","ref":"LoggerTelegramBackend.HTTPClient.html#t:headers/0"},{"type":"type","title":"LoggerTelegramBackend.HTTPClient.method/0","doc":"HTTP request method.","ref":"LoggerTelegramBackend.HTTPClient.html#t:method/0"},{"type":"type","title":"LoggerTelegramBackend.HTTPClient.status/0","doc":"HTTP response status.","ref":"LoggerTelegramBackend.HTTPClient.html#t:status/0"},{"type":"type","title":"LoggerTelegramBackend.HTTPClient.url/0","doc":"HTTP request URL.","ref":"LoggerTelegramBackend.HTTPClient.html#t:url/0"},{"type":"module","title":"LoggerTelegramBackend.HTTPClient.Finch","doc":"The built-in HTTP client based on [finch](https://github.com/sneako/finch).\n\nThis client implements the `LoggerTelegramBackend.HTTPClient` behaviour.\n\nSee `LoggerTelegramBackend` for the available configuration options and\n`LoggerTelegramBackend.HTTPClient` if you wish to use another HTTP client.","ref":"LoggerTelegramBackend.HTTPClient.Finch.html"},{"type":"module","title":"LoggerTelegramBackend.HTTPClient.Hackney","doc":"The built-in HTTP client based on [hackney](https://github.com/benoitc/hackney).\n\nThis client implements the `LoggerTelegramBackend.HTTPClient` behaviour.\n\nSee `LoggerTelegramBackend` for the available configuration options and\n`LoggerTelegramBackend.HTTPClient` if you wish to use another HTTP client.","ref":"LoggerTelegramBackend.HTTPClient.Hackney.html"},{"type":"extras","title":"LoggerTelegramBackend","doc":"# LoggerTelegramBackend\n\n[![Build Status](https://github.com/adriankumpf/logger-telegram-backend/workflows/CI/badge.svg)](https://github.com/adriankumpf/logger-telegram-backend/actions)\n[![Docs](https://img.shields.io/badge/hex-docs-green.svg?style=flat)](https://hexdocs.pm/logger_telegram_backend)\n[![Hex.pm](https://img.shields.io/hexpm/v/logger_telegram_backend?color=%23714a94)](http://hex.pm/packages/logger_telegram_backend)\n\n \n\nA logger backend for [Telegram](https://telegram.org/).","ref":"readme.html"},{"type":"extras","title":"Installation - LoggerTelegramBackend","doc":"Add `:logger_telegram_backend`, `:logger_backends` and `:finch` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:logger_telegram_backend, \"~> 3.0-rc\"},\n    {:logger_backends, \"~> 1.0\"},\n    {:finch, \"~> 1.18\"},\n  ]\nend\n```\n\nIn your `Application.start/2` callback, add the `LoggerTelegramBackend` backend:\n\n```elixir\n@impl true\ndef start(_type, _args) do\n  LoggerBackends.add(LoggerTelegramBackend)\n\n  # ...\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - LoggerTelegramBackend","doc":"First you need to create a [Telegram Bot](https://core.telegram.org/bots). Follow the [instructions here](https://core.telegram.org/bots#6-botfather) to create one and get the `token` for the bot. You will need to send a message first as bots are not allowed to contact users. Then retrieve your `chat_id` with `$ curl -X GET https://api.telegram.org/botYOUR_TOKEN/getUpdates`.\n\nThen configure the telegram `chat_id` and bot `token`:\n\n```elixir\nconfig :logger, LoggerTelegramBackend,\n  chat_id: \"$chatId\",\n  token: \"$botToken\"\n```\n\n#","ref":"readme.html#configuration"},{"type":"extras","title":"Options - LoggerTelegramBackend","doc":"The available options are:\n\n- `:level` - the level to be logged by this backend (either `:debug`, `:info`, `:warning` or `:error`).\n\n  Note that messages are first filtered by the general `:level` configuration for the `:logger` application.\n\n  Default: `nil` (all levels are logged)\n\n- `:metadata` - the metadata to be included in the message. Setting `:metadata` to `:all` will get all metadata.\n  Default: `[:line, :function, :module, :application, :file]`.\n\n- `:metadata_filter` - the metadata which is required in order for a message to be logged.\n\n  Default: `nil`\n\n- `:client` - If you need different functionality for the HTTP client, you can define your own module that implements the `LoggerTelegramBackend.HTTPClient` behaviour and set `client` to that module.\n\n  By default, selects the first client in the list whose application is loaded:\n\n  - `LoggerTelegramBackend.HTTPClient.Finch` (requires `:finch`)\n  - `LoggerTelegramBackend.HTTPClient.Hackney` (requires`:hackney`)\n\n- `:client_pool_opts` - The options passed to configure the pool.\n\n  See [Finch](https://hexdocs.pm/finch/Finch.html#start_link/1) or [Hackney](https://hexdocs.pm/hackney/).\n\n  Default: `[]`\n\n- `:client_request_opts` - The options passed on every request.\n\n  See [Finch](https://hexdocs.pm/finch/Finch.html#request/3) or [Hackney](https://hexdocs.pm/hackney/).\n\n  Default: `[]`\n\n#","ref":"readme.html#options"},{"type":"extras","title":"Examples - LoggerTelegramBackend","doc":"##","ref":"readme.html#examples"},{"type":"extras","title":"Custom HTTP client - LoggerTelegramBackend","doc":"1. Add a module that implements the `LoggerTelegramBackend.HTTPClient` behaviour\n2. Pass your client module to the `:client` option:\n\n   ```elixir\n   config :logger, LoggerTelegramBackend,\n     client: MyClient,\n     # ...\n   ```\n\n##","ref":"readme.html#custom-http-client"},{"type":"extras","title":"Metadata filter - LoggerTelegramBackend","doc":"```elixir\nconfig :logger, LoggerTelegramBackend,\n  chat_id: \"$chatId\",\n  token: \"$botToken\",\n  level: :info,\n  metadata: :all,\n  metadata_filter: [application: :ui]\n```\n\n##","ref":"readme.html#metadata-filter"},{"type":"extras","title":"SOCKS5 proxy - LoggerTelegramBackend","doc":"```elixir\nconfig :logger, LoggerTelegramBackend,\n  chat_id: \"$chatId\",\n  token: \"$botToken\",\n  client: LoggerTelegramBackend.HTTPClient.Hackney,\n  client_request_opts: [\n    proxy: {:socks5, ~c\"127.0.0.1\", 9050}\n  ]\n```\n\nSee the [hackney docs](https://github.com/benoitc/hackney#proxy-a-connection) for further information.","ref":"readme.html#socks5-proxy"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [3.0.0-rc.1] - 2023-08-03\n\n#","ref":"changelog.html"},{"type":"extras","title":"Changes - Changelog","doc":"- Add HTTP client for `Finch`\n\n## [3.0.0-rc.0] - 2023-08-06\n\n#","ref":"changelog.html#changes"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Allow to customize the HTTP client\n- Remove `:proxy` option\n\n#","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Changes - Changelog","doc":"- Log a warning if sending fails\n\n#","ref":"changelog.html#changes"},{"type":"extras","title":"Bug fixes - Changelog","doc":"- Escape metadata fields\n- Fix deprecation warnings\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Upgrade Instructions - Changelog","doc":"##","ref":"changelog.html#upgrade-instructions"},{"type":"extras","title":"Migrate to `:logger_backends` - Changelog","doc":"If you are using Elixir 1.15, add `:logger_telegram_backend` to your list of dependencies in `mix.exs`:\n\n```elixir\n  def deps do\n    [\n      {:logger_telegram_backend, \"~> 3.0-rc\"},\n      {:logger_backends, \"~> 1.0\"}\n    ]\n  end\n```\n\nIn your `Application.start/2` callback, add the `LoggerTelegramBackend` backend:\n\n```elixir\n@impl true\ndef start(_type, _args) do\n  LoggerBackends.add(LoggerTelegramBackend)\n\n  # ...\nend\n```\n\nRemove the `:backends` configuration from `:logger`:\n\n```elixir\nconfig :logger,\n  # Remove this line\n  backends: [LoggerTelegramBackend, :console]\n```\n\n##","ref":"changelog.html#migrate-to-logger_backends"},{"type":"extras","title":"Config - Changelog","doc":"Configuration is now done via `config :logger, LoggerTelegramBackend`.\n\n**Before:**\n\n```elixir\nconfig :logger, :telegram,\n  # ...\n```\n\n**After:**\n\n```elixir\nconfig :logger, LoggerTelegramBackend,\n  # ...\n```\n\n##","ref":"changelog.html#config"},{"type":"extras","title":"HTTP client (optional) - Changelog","doc":"Remove the `:adapter` configuration:\n\n```elixir\nconfig :logger, LoggerTelegramBackend,\n  # Remove this line\n  adapter: {Tesla.Adapter.Finch, name: MyFinch}\n```\n\nAdd the `:client` option and pass your own module that implements the `LoggerTelegramBackend.HTTPClient` behaviour:\n\n```elixir\nconfig :logger, LoggerTelegramBackend,\n  client: MyFinchClient\n```\n\nSee the documentation for `LoggerTelegramBackend.HTTPClient` and the README for more information.\n\n##","ref":"changelog.html#http-client-optional"},{"type":"extras","title":"SOCKS5 Proxy (optional) - Changelog","doc":"Remove the `:proxy` configuration:\n\n```elixir\nconfig :logger, LoggerTelegramBackend,\n  # Remove this line\n  proxy: \"socks5://127.0.0.1:9050\"\n```\n\nAnd add the following `:hackney_opts`:\n\n```elixir\nconfig :logger, LoggerTelegramBackend,\n  hackney_opts: [\n    ssl: [verify: :verify_none],\n    hackney: [insecure: true],\n    proxy: {:socks5, ~c\"127.0.0.1\", 9050}\n  ]\n```\n\n## [2.0.1] - 2021-05-02\n\n#","ref":"changelog.html#socks5-proxy-optional"},{"type":"extras","title":"Fixed - Changelog","doc":"- Don't crash if sending an event does not succeed\n\n## [2.0.0] - 2020-12-22\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Use [tesla](https://github.com/teamon/tesla) to make the underlying HTTP client configurable\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Make hackney an optional dependency. To use the default `hackney` based adapter, add it to the list of dependencies:\n\n  ```elixir\n  def deps do\n    [\n      {:logger_telegram_backend, \"~> 2.0.0\"},\n      {:hackney, \"~> 1.17\"}\n    ]\n  end\n  ```\n\n## [1.3.0] - 2019-07-22\n\n#","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Changed - Changelog","doc":"- Respect maximum message length to avoid [MESSAGE_TOO_LONG errors](https://core.telegram.org/method/messages.sendMessage#return-errors)\n- Bump ex_doc from 0.20.2 to 0.21.1\n\n## [1.2.1] - 2019-05-27\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Bump httpoison from 1.4.0 to 1.5.1\n- Bump ex_doc from 0.19.1 to 0.20.2\n\n## [1.2.0] - 2018-11-28\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Add proxy support (from [@mvalitov](https://github.com/mvalitov))\n\n## [1.1.0] - 2018-11-26\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Remove dependency on `Poison`: the success of a request is now solely determined by the HTTP status code.\n- Remove `GenStage` and simplify the overall event handling logic\n- Update dependencies\n\n## [1.0.3] - 2018-05-25\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Add `@impl` attributes\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Update dependencies\n- Format code\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fix typo in README\n\n## [1.0.2] - 2018-03-01\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Update `httpoison` to 1.0\n\n## [1.0.1] - 2018-02-10\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Update Dependencies\n\n## [1.0.0] - 2018-01-14\n\n[3.0.0-rc.1]: https://github.com/adriankumpf/logger-telegram-backend/compare/v3.0.0-rc.0...v3.0.0-rc.1\n[3.0.0-rc.0]: https://github.com/adriankumpf/logger-telegram-backend/compare/v2.0.1...v3.0.0-rc.0\n[2.0.1]: https://github.com/adriankumpf/logger-telegram-backend/compare/v2.0.0...v2.0.1\n[2.0.0]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.3.0...v2.0.0\n[1.3.0]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.2.1...v1.3.0\n[1.2.1]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.2.0...v1.2.1\n[1.2.0]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.1.0...v1.2.0\n[1.1.0]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.0.3...v1.1.0\n[1.0.3]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.0.2...v1.0.3\n[1.0.2]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.0.1...v1.0.2\n[1.0.1]: https://github.com/adriankumpf/logger-telegram-backend/compare/v1.0.0...v1.0.1\n[1.0.0]: https://github.com/adriankumpf/logger-telegram-backend/compare/v0.1.0...v1.0.0","ref":"changelog.html#changed"}],"content_type":"text/markdown"}